#
# @ 2023. Triad National Security, LLC. All rights reserved.
#
# This program was produced under U.S. Government contract 89233218CNA000001
# for Los Alamos National Laboratory (LANL), which is operated by Triad
# National Security, LLC for the U.S. Department of Energy/National Nuclear
# Security Administration. All rights in the program are reserved by Triad
# National Security, LLC, and the U.S. Department of Energy/National Nuclear
# Security Administration. The Government is granted for itself and others acting
# on its behalf a nonexclusive, paid-up, irrevocable worldwide license in this
# material to reproduce, prepare derivative works, distribute copies to the
# public, perform publicly and display publicly, and to permit others to do so.
#
# Author: Yu Zhang <zhy@lanl.gov>
#


import os
import sys
import textwrap

# TODO: extract it from __version__.py
__version__ = "0.1.0.beta"

__author__ = "Yu Zhang (zhy@lanl.gov)"
__copyright__ = f"""
{" " * 3}
{" " * 3} @ 2023. Triad National Security, LLC. All rights reserved.
{" " * 3}
{" " * 3}This program was produced under U.S. Government contract 89233218CNA000001
{" " * 3} for Los Alamos National Laboratory (LANL), which is operated by Triad
{" " * 3}National Security, LLC for the U.S. Department of Energy/National Nuclear
{" " * 3}Security Administration. All rights in the program are reserved by Triad
{" " * 3}National Security, LLC, and the U.S. Department of Energy/National Nuclear
{" " * 3}Security Administration. The Government is granted for itself and others acting
{" " * 3}on its behalf a nonexclusive, paid-up, irrevocable worldwide license in this
{" " * 3}material to reproduce, prepare derivative works, distribute copies to the
{" " * 3}
{" " * 3}Authors: Yu Zhang <zhy@lanl.gov>
"""

__logo__ = f"""
TBA
{__copyright__}
Version: {__version__}
"""




import re
import numpy

from setuptools import setup, find_packages
from setuptools.extension import Extension



def version_number(path: str) -> str:
    """Get the version number from the src directory"""
    print("verison path is", path)

    exp = r'__version__[ ]*=[ ]*["\']([^"\']+)["\']'
    version_re = re.compile(exp)


    with open(path, 'r') as file:
        content = file.read()

    match = version_re.search(content)
    if match:
        version = match.group(1)
        print("version is", version)
        return version
    else:
        raise ValueError("Version number not found in the specified file")
        #return None

def load_requirements(filename):
    r"""
    load requirement and return the list
    """
    with open(filename, 'r') as file:
        return file.read().splitlines()


def main() -> None:
    version_path = "qubitchem/__version__.py"
    __version__ = version_number(version_path)
    if __version__ is None:
        raise ValueError("Version information not found in " + version_path)

    setup(
        name='QubitChem',
        version=__version__,
        author='Yu Zhang',
        author_email='zhyhku@gmail.com',
        description='Quantum Chemistry solvers on qubits',
        long_description=open('README.md').read(),
        long_description_content_type='text/markdown',
        url='https://github.com/TBA',
        packages=find_packages(exclude=["examples", "docs", "tests", "tools", "setup.py"]),
        python_requires='>=3.6',
        install_requires=load_requirements("requirements.txt"),
    )

if __name__ == "__main__":
    main()
